%define base_version	1.6.0
%define pre		beta2
%define minor_version	1
%if %pre
%define release		%mkrel 0.%pre.1
%define version		%base_version
%define distname	%name-%version-%pre
%else
%define release		%mkrel 3
%define version		%base_version.%minor_version
%define distname	%name-%version
%endif

Summary:	Music DJing software
Name:		mixxx
Version:	%{version}
Release:	%{release}
Group:		Sound
License:	GPLv2+
URL:		http://mixxx.sourceforge.net/
Source:		http://downloads.sourceforge.net/mixxx/%{distname}-src.tar.gz
# Remove the djconsole test, as it doesn't seem to work - AdamW 2008/03
Patch0:		mixxx-1.6.0-djconsole.patch
# Fix up the menu entry for MDV standards - AdamW 2008/03
Patch1:		mixxx-1.6.0-desktop.patch
# Allow custom optflags to be specified as a build parameter, letting
# us use the MDV optflags: with thanks to misc for python help :)
# - AdamW 2008/03
Patch2:		mixxx-1.6.0-optflags.patch
BuildRequires:	libsndfile-static-devel
BuildRequires:	qt4-devel 
BuildRequires:	fftw-devel 
BuildRequires:	libogg-devel 
BuildRequires:	libvorbis-devel 
BuildRequires:	jackit-devel
BuildRequires:	audiofile-devel 
BuildRequires:	libid3tag-devel 
BuildRequires:	mad-devel
BuildRequires:	mesaglu-devel 
BuildRequires:	alsa-lib-devel
BuildRequires:	portaudio-devel >= 0.19
BuildRequires:	libdjconsole-devel
BuildRequires:	libusb-devel
BuildRequires:	sed
BuildRequires:	scons
BuildRequires:	qt4-linguist
%py_requires -d
BuildRoot:	%{_tmppath}/%{name}-%{version}-buildroot

%description
Mixxx allows DJs to mix music live with a clean, simple interface.
Futhermore, Mixxx has a number of key features to help DJs in the mix:
Beat estimation, parallel visual displays, and support for various DJ
hardware controllers.

Mixxx can be controlled through the GUI using the mouse, or by
connecting MIDI devices to the computer. Commercial and custom build
MIDI controllers can be used. The mapping between functions and MIDI
controller values are done in text files. 

%prep
%if %pre
%setup -q -n %{name}-%{base_version}%{pre}
%else
%setup -q -n %{name}-%{base_version}
%endif
%patch0 -p1 -b .djconsole
%patch1 -p1 -b .desktop
%patch2 -p1 -b .optflags

%build
export PKG_CONFIG_PATH=$PKG_CONFIG_PATH:%{qt4lib}/pkgconfig

sed -i -e "s|QTDIR\/lib|QTDIR\/%{_lib}|g" \
	src/SConscript
sed -i -e "s|lib\/libqt-mt|%{_lib}\/libqt-mt|g" \
	src/build.definition

scons %{_smp_mflags} prefix=%{_prefix} install_root=%{buildroot}%{_prefix} qtdir=%{qt4dir} djconsole=1 optimize="%{optflags}"

%install
rm -rf %{buildroot}
export PKG_CONFIG_PATH=$PKG_CONFIG_PATH:%{qt4lib}/pkgconfig
mkdir -p %{buildroot}%{_prefix}
scons %{_smp_mflags} install prefix=%{_prefix} install_root=%{buildroot}%{_prefix} qtdir=%{qt4dir} djconsole=1 optimize="%{optflags}"
rm -fr %{buildroot}/%{_docdir}

mkdir -p %{buildroot}%{_datadir}/applications
install -m644 src/mixxx.desktop %{buildroot}%{_datadir}/applications

mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,32x32,48x48,128x128,scalable}/apps

install -m644 src/iconsmall.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/mixxx-icon.png
install -m644 src/iconlarge.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/mixxx-icon.png
install -m644 src/iconhuge.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/mixxx-icon.png
install -m644 src/icon.png %{buildroot}%{_iconsdir}/hicolor/128x128/apps/mixxx-icon.png
install -m644 src/icon.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/mixxx-icon.png

# not needed
rm -rf %{buildroot}%{_datadir}/pixmaps

%clean
rm -rf %{buildroot}

%if %mdkversion < 200900
%post
%{update_menus}
%{update_icon_cache hicolor}
%endif

%if %mdkversion < 200900
%postun
%{clean_menus}
%{clean_icon_cache hicolor}
%endif

%files
%defattr(-,root,root)
%doc COPYING README LICENSE README.macro HERCULES.txt 
%doc Mixxx-Manual.pdf
%{_bindir}/%{name}
%{_iconsdir}/*/*/apps/mixxx-icon.*
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop



%changelog
* Tue Jul 29 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.6.0-0.beta2.1mdv2009.0
+ Revision: 252544
- rebuild

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Fri Mar 07 2008 Adam Williamson <awilliamson@mandriva.com> 1.6.0-0.beta2.1mdv2008.1
+ Revision: 181218
- install .svg icon as well as .pngs
- adapt %%build and %%install to scons-based buildsystem, drop unnecessary substitutions
- update description
- update buildrequires for qt4 and scons-based buildsystem
- add optflags.patch (patches the build script to allow custom optflags, with thanks to misc for the python syntax help)
- add desktop.patch (fix up menu entry for MDV standards)
- add djconsole.patch (the build's test for libdjconsole doesn't seem to work for some reason, so disable the test and just assume it's present)
- drop djconsole-usb.patch (no longer needed, upstream uses pkg-config now)
- drop python-config.patch (no longer relevant)
- new license policy
- add conditionals to gracefully handle pre-release build
- new release 1.6.0 beta 2 (requested by Anne)

* Mon Feb 18 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.5.0.1-4mdv2008.1
+ Revision: 170982
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Aug 20 2007 Oden Eriksson <oeriksson@mandriva.com> 1.5.0.1-3mdv2008.0
+ Revision: 67909
- rebuilt against new portaudio libs

* Sun Jun 24 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.0.1-2mdv2008.0
+ Revision: 43661
- fix bug #31551
- add scriplets

* Sat Jun 16 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.0.1-1mdv2008.0
+ Revision: 40422
- add buildrequires on usb-devel
- fix building on x86_64
- added missing buildrequires
- spec file clean

  + Helio Chissini de Castro <helio@mandriva.com>
    - Added patch to fix djconsole build against libusb
    - New and revamped mixxx for Mandriva
    - Added support for libdjconsole \o/.
    - Added support for scripting back ( bad python config test )
    - Removed ols debian like menu
    - Added proper desktop file and their official icons
    - Restored portaudio build.
      Lets's have some fun !!


* Tue Sep 05 2006 Emmanuel Andry <eandry@mandriva.org> 1.4.2-3mdv2007.0
- xdg menu
- fix buildrequires

* Wed Jun 22 2005 Tibor Pittich <Tibor.Pittich@mandriva.org> 1.4.2-2mdk
- include README.ALSA
- use mkrel

* Fri Jan 14 2005 Tibor Pittich <Tibor.Pittich@mandrake.org> 1.4.2-1mdk
- 1.4.2
- update configure parameters

* Thu Oct 14 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 1.4.1-1mdk
- 1.4.1

* Tue Oct 12 2004 Austin Acton <austin@mandrake.org> 1.4-1mdk
- 1.4

* Tue Sep 28 2004 Franck Villaume <fvill@freesurf.fr> 1.3.2-3mdk
- more BuildRequires

* Mon Sep 27 2004 Franck Villaume <fvill@freesurf.fr> 1.3.2-2mdk
- BuildRequires

* Tue Jul 27 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 1.3.2-1mdk
- 1.3.2
- added patch to allow buid with alsa support, enabled both jack and alsa
- cosmetics, added documentation

* Sun Jul 11 2004 Michael Scherer <misc@mandrake.org> 1.2.1-3mdk 
- rebuid for new gcc (patch #0)

* Mon Mar 22 2004 Austin Acton <austin@mandrake.org> 1.2.1-2mdk
- fix installation

* Mon Feb 16 2004 Austin Acton <austin@mandrake.org> 1.2.1-1mdk
- 1.2.1

* Tue Dec 30 2003 Austin Acton <austin@linux.ca> 1.2-1mdk
- 1.2
- link to local libs

* Mon Oct 06 2003 Austin Acton <aacton@yorku.ca> 1.0-1mdk
- 1.0
- delib buildrequires

